==> forms-v5.2.1.tar.gz: forms/l10n/he.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "טפסים",
    "Copy" : "העתק",
    "Anonymous response" : "תגובה אלמונית",
    "Shared by %s" : "שותף על ידי %s",
    "responses" : "תגובות",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 סקריםי ושאלונים פשוטים, באירוח עצמי",
    "An error occurred while loading the forms list" : "אירעה שגיאה בעת טעינת רשימת הטפסים",
    "Form not found" : "הטופס לא נמצא",
    "Unable to create a new form" : "לא ניתן ליצור טופס חדש",
    "New form" : "טופס חדש",
    "Shared with you" : "משותף אתך",
    "Loading forms …" : "הטפסים נטענים…",
    "No forms created yet" : "לא נוצרו עדיין טפסים",
    "Create a form" : "יצירת טופס",
    "Select a form or create a new one" : "ניתן לבחור טופס או ליצור אחד חדש",
    "Create new form" : "יצירת טופס חדש",
    "This form does not exist" : "טופס זה אינו קיים",
    "Form expired" : "תוקף הטופס פג",
    "This form has expired and is no longer taking answers" : "תוקפו של טופס זה פג ולא ניתן לענות עליו עוד",
    "Select groups" : "בחירת קבוצות",
    "Delete form" : "מחיקת טופס",
    "Error while deleting {title}" : "שגיאה במחיקת {title}",
    "Share form" : "שיתוף טופס",
    "Are you sure you want to delete {title}?" : "למחוק את {title}?",
    "Cancel" : "ביטול",
    "Options" : "אפשרויות",
    "Answer number {index}" : "תשובה מספר {index}",
    "Error while saving the answer" : "שגיאה בעת שמירת התשובה",
    "Delete answer" : "מחיקת תשובה",
    "This question needs a title!" : "לשאלה זו דרושה כותרת!",
    "Question number {index}" : "שאלה מספר {index}",
    "Title of question number {index}" : "כותרת של שאלה מספר {index}",
    "Required" : "נדרש",
    "Delete question" : "מחיקת שאלה",
    "Maximum file size" : "גודל הקובץ המרבי",
    "Delete" : "מחיקה",
    "Uploading …" : "מתבצעת העלאה…",
    "A long answer for the question “{text}”" : "תשובה ארוכה לשאלה „{text}”",
    "Other" : "אחר",
    "A short answer for the question “{text}”" : "תשובה קצרה לשאלה „{text}”",
    "No response" : "אין תגובה",
    "Delete this response" : "מחיקת התגובה הזאת",
    "Expired on {date}" : "התוקף פג ב־{date}",
    "Expires on {date}" : "התוקף יפוג ב־{date}",
    "never" : "מעולם לא",
    "Allow multiple responses per person" : "לאפשר מספר תגובות למשתתף",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Group" : "קבוצה",
    "Permissions" : "הרשאות",
    "Share link" : "קישור שיתוף",
    "Add link" : "הוספת קישור",
    "Copy to clipboard" : "העתקה ללוח הגזירים",
    "Copy embedding code" : "העתקת קוד הטמעה",
    "Internal link" : "קישור פנימ",
    "View" : "צפייה",
    "Edit" : "עריכה",
    "View mode" : "מצב הצגה",
    "Share" : "שתף",
    "Responses are anonymous." : "התגובות אלמוניות.",
    "An asterisk (*) indicates mandatory questions." : "כוכבית (*) מציינת שאלות חובה.",
    "There was an error while adding the new question" : "אירעה שגיאה בעת הוספת השאלה החדשה",
    "There was an error while removing the question" : "אירעה שגיאה בעת הסרת השאלה",
    "Error while saving form" : "שגיאה בעת שמירת טופס",
    "Loading {title} …" : "{title} בטעינה…",
    "Form title" : "כותרת טופס",
    "Description" : "תיאור",
    "Add a question" : "הוספת שאלה",
    "Summary" : "תקציר",
    "Responses" : "תגובות",
    "There was an error while loading the results" : "אירעה שגיאה בטעינת התוצאות",
    "There was an error while removing this response" : "אירעה שגיאה בהסרת התגובה הזאת",
    "There was an error while removing responses" : "אירעה שגיאה בעת הסרת התגובות",
    "{amount} responses" : "{amount} תגובות",
    "Download" : "הורדה",
    "Delete all responses" : "מחיקת כל התגובות",
    "Search" : "חיפוש",
    "Loading responses …" : "התגובות נטענות…",
    "No responses yet" : "אין תגובות עדיין",
    "Results of submitted forms will show up here" : "התוצאות לטפסים שהוגשו תופענה כאן",
    "Are you sure you want to delete all responses of {title}?" : "למחוק את כל התגובות על {title}?",
    "Sharing" : "שיתוף",
    "Settings" : "הגדרות",
    "Abort" : "להפסיק",
    "Submit" : "שליחה",
    "Clear" : "פינוי",
    "There was an error submitting the form" : "עלתה שגיאה בעת הגשת הטופס",
    "Submit form" : "הגשת הטופס",
    "Submitting form …" : "הטופס מוגש…",
    "Thank you for completing the form!" : "תודה לך על שהשלמת את הטופס!",
    "Error while saving question" : "שגיאה בשמירת השאלה",
    "There was an issue deleting this option" : "מחיקת האפשרות נתקלה בבעיה",
    "Form link copied" : "קישור הטופס הועתק",
    "Cannot copy, please copy the link manually" : "לא ניתן להעתיק, נא להעתיק את הקישור ידנית",
    "No recommendations. Start typing." : "אין המלצות. נא להתחיל להקליד.",
    "No elements found." : "לא נמצאו רכיבים.",
    "Checkboxes" : "תיבות סימון",
    "Checkbox question title" : "כותרת שאלת תיבות סימון",
    "This question needs a title and at least one answer!" : "שאלה זו זקוקה לכותרת ולפחות לתשובה אחת!",
    "Dropdown" : "תפריט נפתח",
    "Dropdown question title" : "כותרת שאלת תפריט נפתח",
    "People can pick one option" : "המשתתפים יכולים לבחור באפשרות אחת",
    "Pick an option" : "נא לבחור באפשרות",
    "File" : "קובץ",
    "Short answer" : "תשובה קצרה",
    "Short answer question title" : "כותרת שאלה לתשובה קצרה",
    "People can enter a short answer" : "המשתתפים יכולים למלא תשובה קצרה",
    "Long text" : "טקסט ארוך",
    "Long text question title" : "כותרת שאלה טקסט ארוך",
    "People can enter a long text" : "משתתפים יכולים למלא טקסט ארוך",
    "Date" : "תאריך",
    "People can pick a date" : "אנשים יכולים לבחור תאריך",
    "Pick a date" : "נא לבחור תאריך",
    "Datetime" : "תאריך ושעה",
    "People can pick a date and time" : "אנשים יכולים לבחור תאריך ושעה",
    "Pick a date and time" : "נא לבחור תאריך ושעה",
    "Time" : "זמן",
    "Pick a time" : "בחר זמן",
    "Color" : "צבע",
    "Image" : "תמונה",
    "Document" : "מסמך",
    "Presentation" : "מצגת",
    "Spreadsheet" : "גיליון נתונים",
    "Text" : "טקסט",
    "Phone number" : "מספר טלפון",
    "Email address" : "כתובת דוא״ל"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");

==> forms-v5.2.2.tar.gz: forms/l10n/he.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "טפסים",
    "Copy" : "העתק",
    "Anonymous response" : "תגובה אלמונית",
    "Shared by %s" : "שותף על ידי %s",
    "responses" : "תגובות",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 סקריםי ושאלונים פשוטים, באירוח עצמי",
    "An error occurred while loading the forms list" : "אירעה שגיאה בעת טעינת רשימת הטפסים",
    "Form not found" : "הטופס לא נמצא",
    "Unable to create a new form" : "לא ניתן ליצור טופס חדש",
    "New form" : "טופס חדש",
    "Shared with you" : "משותף אתך",
    "No forms created yet" : "לא נוצרו עדיין טפסים",
    "Create a form" : "יצירת טופס",
    "Select a form or create a new one" : "ניתן לבחור טופס או ליצור אחד חדש",
    "Create new form" : "יצירת טופס חדש",
    "This form does not exist" : "טופס זה אינו קיים",
    "Form expired" : "תוקף הטופס פג",
    "This form has expired and is no longer taking answers" : "תוקפו של טופס זה פג ולא ניתן לענות עליו עוד",
    "Select groups" : "בחירת קבוצות",
    "Delete form" : "מחיקת טופס",
    "Error while deleting {title}" : "שגיאה במחיקת {title}",
    "Share form" : "שיתוף טופס",
    "Are you sure you want to delete {title}?" : "למחוק את {title}?",
    "Cancel" : "ביטול",
    "Options" : "אפשרויות",
    "Answer number {index}" : "תשובה מספר {index}",
    "Error while saving the answer" : "שגיאה בעת שמירת התשובה",
    "Delete answer" : "מחיקת תשובה",
    "This question needs a title!" : "לשאלה זו דרושה כותרת!",
    "Question number {index}" : "שאלה מספר {index}",
    "Title of question number {index}" : "כותרת של שאלה מספר {index}",
    "Required" : "נדרש",
    "Delete question" : "מחיקת שאלה",
    "Maximum file size" : "גודל הקובץ המרבי",
    "Delete" : "מחיקה",
    "A long answer for the question “{text}”" : "תשובה ארוכה לשאלה „{text}”",
    "Other" : "אחר",
    "A short answer for the question “{text}”" : "תשובה קצרה לשאלה „{text}”",
    "No response" : "אין תגובה",
    "Delete this response" : "מחיקת התגובה הזאת",
    "Expired on {date}" : "התוקף פג ב־{date}",
    "Expires on {date}" : "התוקף יפוג ב־{date}",
    "never" : "מעולם לא",
    "Allow multiple responses per person" : "לאפשר מספר תגובות למשתתף",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Group" : "קבוצה",
    "Permissions" : "הרשאות",
    "Share link" : "קישור שיתוף",
    "Add link" : "הוספת קישור",
    "Copy to clipboard" : "העתקה ללוח הגזירים",
    "Copy embedding code" : "העתקת קוד הטמעה",
    "Internal link" : "קישור פנימ",
    "View" : "צפייה",
    "Edit" : "עריכה",
    "View mode" : "מצב הצגה",
    "Share" : "שתף",
    "Responses are anonymous." : "התגובות אלמוניות.",
    "An asterisk (*) indicates mandatory questions." : "כוכבית (*) מציינת שאלות חובה.",
    "There was an error while adding the new question" : "אירעה שגיאה בעת הוספת השאלה החדשה",
    "There was an error while removing the question" : "אירעה שגיאה בעת הסרת השאלה",
    "Error while saving form" : "שגיאה בעת שמירת טופס",
    "Form title" : "כותרת טופס",
    "Description" : "תיאור",
    "Add a question" : "הוספת שאלה",
    "Summary" : "תקציר",
    "Responses" : "תגובות",
    "There was an error while loading the results" : "אירעה שגיאה בטעינת התוצאות",
    "There was an error while removing this response" : "אירעה שגיאה בהסרת התגובה הזאת",
    "There was an error while removing responses" : "אירעה שגיאה בעת הסרת התגובות",
    "{amount} responses" : "{amount} תגובות",
    "Download" : "הורדה",
    "Delete all responses" : "מחיקת כל התגובות",
    "Search" : "חיפוש",
    "No responses yet" : "אין תגובות עדיין",
    "Results of submitted forms will show up here" : "התוצאות לטפסים שהוגשו תופענה כאן",
    "Are you sure you want to delete all responses of {title}?" : "למחוק את כל התגובות על {title}?",
    "Sharing" : "שיתוף",
    "Settings" : "הגדרות",
    "Abort" : "להפסיק",
    "Submit" : "שליחה",
    "Clear" : "פינוי",
    "There was an error submitting the form" : "עלתה שגיאה בעת הגשת הטופס",
    "Submit form" : "הגשת הטופס",
    "Thank you for completing the form!" : "תודה לך על שהשלמת את הטופס!",
    "Error while saving question" : "שגיאה בשמירת השאלה",
    "There was an issue deleting this option" : "מחיקת האפשרות נתקלה בבעיה",
    "Form link copied" : "קישור הטופס הועתק",
    "Cannot copy, please copy the link manually" : "לא ניתן להעתיק, נא להעתיק את הקישור ידנית",
    "No recommendations. Start typing." : "אין המלצות. נא להתחיל להקליד.",
    "No elements found." : "לא נמצאו רכיבים.",
    "Checkboxes" : "תיבות סימון",
    "Checkbox question title" : "כותרת שאלת תיבות סימון",
    "This question needs a title and at least one answer!" : "שאלה זו זקוקה לכותרת ולפחות לתשובה אחת!",
    "Dropdown" : "תפריט נפתח",
    "Dropdown question title" : "כותרת שאלת תפריט נפתח",
    "People can pick one option" : "המשתתפים יכולים לבחור באפשרות אחת",
    "Pick an option" : "נא לבחור באפשרות",
    "File" : "קובץ",
    "Short answer" : "תשובה קצרה",
    "Short answer question title" : "כותרת שאלה לתשובה קצרה",
    "People can enter a short answer" : "המשתתפים יכולים למלא תשובה קצרה",
    "Long text" : "טקסט ארוך",
    "Long text question title" : "כותרת שאלה טקסט ארוך",
    "People can enter a long text" : "משתתפים יכולים למלא טקסט ארוך",
    "Date" : "תאריך",
    "People can pick a date" : "אנשים יכולים לבחור תאריך",
    "Pick a date" : "נא לבחור תאריך",
    "Datetime" : "תאריך ושעה",
    "People can pick a date and time" : "אנשים יכולים לבחור תאריך ושעה",
    "Pick a date and time" : "נא לבחור תאריך ושעה",
    "Time" : "זמן",
    "Pick a time" : "בחר זמן",
    "Color" : "צבע",
    "Image" : "תמונה",
    "Document" : "מסמך",
    "Presentation" : "מצגת",
    "Spreadsheet" : "גיליון נתונים",
    "Text" : "טקסט",
    "Phone number" : "מספר טלפון",
    "Email address" : "כתובת דוא״ל",
    "Loading forms …" : "הטפסים נטענים…",
    "Uploading …" : "מתבצעת העלאה…",
    "Loading {title} …" : "{title} בטעינה…",
    "Loading responses …" : "התגובות נטענות…",
    "Submitting form …" : "הטופס מוגש…"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
